@@ -32,7 +32,7 @@ class Morpher:
         self.plane1.wireframe(False).alpha(1).lineWidth(0.1).c('white').lc('grey5')
         self.plane2 = self.plane1.clone().pickable(False)
 
-        self.plotter = Plotter(N=2, bg='light blue', size=(2000,1000))
+        self.plotter = Plotter(N=2, bg='light blue', size=(2000,1000), sharecam=0)
         self.plotter.addCallback('left click', self.onleftclick)
         self.plotter.addCallback('right click', self.onrightclick)
         self.plotter.addCallback('key press', self.onkeypress)
@@ -41,7 +41,7 @@ class Morpher:
         paxes = Axes(self.plane1, xyGrid=0, textScale=0.6)
         self.plotter.at(0).show(self.plane1, paxes, self.msg1, self.mesh1, self.mesh2)
         self.plotter.at(1).show(self.plane2, self.msg2, mode='image')
-        if len(self.arrow_starts):
+        if len(self.arrow_starts)>0:
             self.draw(True)
             self.draw(False)
             self.msg1.text(self.instructions)
@@ -53,7 +53,7 @@ class Morpher:
         if toggle:
             self.msg1.text("Choose start point or press:\nm to morph the shapes\ng to interpolate")
             self.plotter.at(0).remove("displacementArrows")
-            if not len(self.arrow_starts): return
+            if len(self.arrow_starts)==0: return
             arrows = Arrows2D(self.arrow_starts, self.arrow_stops, c='red4')
             arrows.name = "displacementArrows"
             self.plotter.add(arrows)
@@ -104,7 +104,7 @@ class Morpher:
 
             self.msg1.text(self.instructions)
             self.msg2.text("Morphed output:")
-            self.plotter.at(1).clear().addRendererFrame().add(output)
+            self.plotter.at(1).clear().addRendererFrame().add(output).resetCamera()
 
         elif evt.keyPressed == 'g':  ##------- generate intermediate shapes
             if not self.dottedln:
