@@ -5,7 +5,7 @@ from vedo import *
 # "depth peeling" may improve the rendering of transparent objects
 settings.useDepthPeeling = True
 settings.multiSamples = 0  # needed on OSX vtk9
- 
+
 man = Mesh(dataurl+"man.vtk")
 
 # let the scalar be the z coordinate of the mesh vertices
@@ -17,7 +17,7 @@ try:
     import numpy as np
     mycmap = colorcet.bmy
     alphas = np.linspace(0.8, 0.2, num=len(mycmap))
-except:
+except ModuleNotFoundError:
     printc("colorcet is not available, use custom cmap", c='y')
     mycmap = ["darkblue", "magenta", (1, 1, 0)]
     alphas = [0.8,              0.6,       0.2]
@@ -28,4 +28,5 @@ except:
 
 man.cmap(mycmap, scals, alpha=alphas).addScalarBar()
 
-show(man, __doc__, viewup="z", axes=7).close()
\ No newline at end of file
+show(man, __doc__, viewup="z", axes=7).close()
+
