@@ -1,5 +1,6 @@
 import numpy as np
-import napari, vedo
+import napari
+import vedo
 
 # Load the surface, triangulate just in case, and compute vertex normals
 surf = vedo.Mesh(vedo.dataurl+"beethoven.ply").triangulate().computeNormals()
@@ -23,4 +24,4 @@ with napari.gui_qt():
     viewer.add_points(vertices, size=0.05, face_color='pink')
 
     # turn on 3D rendering
-    viewer.dims.ndisplay = 3
\ No newline at end of file
+    viewer.dims.ndisplay = 3
