@@ -43,12 +43,6 @@ python qt_window2.py
 echo Running qt_tabs.py # needs qt5
 python3 qt_tabs.py
 
-echo Running self_org_maps2d.py
-python3 self_org_maps2d.py
-
-echo Running value-iteration.py
-python3 value_iteration.py
-
 echo Running remesh_meshfix.py
 python3 remesh_meshfix.py
 
