@@ -14,8 +14,8 @@ G = 0.15 * np.exp(-4 * X**2) # use a  gaussian as a weight
 
 # Generate line plots
 lines = []
-for i in range(len(data)):
-    pts = np.c_[X, np.zeros_like(X)+i/10, G*data[i]]
+for i, d in enumerate(data):
+    pts = np.c_[X, np.zeros_like(X)+i/10, G*d]
     lines.append(Line(pts, lw=3))
 
 # Set up the first frame
@@ -26,10 +26,10 @@ plt = show(lines, __doc__, axes=axes, elevation=-30, interactive=False, bg='k8')
 for i in range(50):
     data[:, 1:] = data[:, :-1]                      # Shift data to the right
     data[:, 0] = np.random.uniform(0, 1, len(data)) # Fill-in new values
-    for i in range(len(data)):                      # Update data
-        newpts = lines[i].points()
-        newpts[:,2] = G * data[i]
-        lines[i].points(newpts).cmap('gist_heat_r', newpts[:,2])
+    for line, d in zip(lines, data):                    # Update data
+        newpts = line.points()
+        newpts[:,2] = G * d
+        line.points(newpts).cmap('gist_heat_r', newpts[:,2])
     plt.render()
     if plt.escaped: break # if ESC is hit during the loop
     # vd.addFrame()
