@@ -1,10 +1,8 @@
-"""Simulation of a block connected
-to a spring in a viscous medium"""
+"""Simulation of a block connected to a spring in a viscous medium"""
 from vedo import *
 
 settings.allowInteraction = True  # allow mouse interaction while playing
 
-plt = Plotter(interactive=0, axes=0)
 
 L = 0.1    # spring x position at rest
 x0 = 0.85  # initial x-coordinate of the block
@@ -20,6 +18,7 @@ xr = vector(L, 0, 0)
 sx0 = vector(-0.8, 0, 0)
 offx = vector(0, 0.3, 0)
 
+plt = Plotter(size=(1050, 600))
 plt += Box(pos=(0, -0.1, 0), length=2.0, width=0.02, height=0.5)  # surface
 plt += Box(pos=(-0.82, 0.15, 0), length=0.04, width=0.50, height=0.3)  # wall
 
@@ -40,7 +39,7 @@ for i in pb.range():
     block.pos(x)  # update block position and trail
     spring.stretch(sx0, x)  # stretch helix accordingly
 
-    plt.show(elevation=0.1, azimuth=0.1)
+    plt.show(elevation=0.1, azimuth=0.1, interactive=False, zoom=1.5)
     if plt.escaped: break # if ESC is hit during the loop
     pb.print()
 
