@@ -1,6 +1,6 @@
 """Custom color and transparency maps for Volumes"""
 from vedo import Volume, dataurl, show
-from vedo.pyplot import cornerHistogram
+from vedo.pyplot import CornerHistogram
 
 # Build a Volume object.
 # A set of color/transparency values - of any length - can be passed
@@ -17,7 +17,7 @@ vol.alpha([0., 1.])
 vol.alphaUnit(8) # absorption unit, higher factors = higher transparency
 vol.addScalarBar3D(title='color~\dot~alpha transfer function', c='k')
 
-ch = cornerHistogram(vol, logscale=True, pos='bottom-left')
+ch = CornerHistogram(vol, logscale=True, pos='bottom-left')
 
 # show both Volume and Mesh
 show(vol, ch, __doc__, axes=1, zoom=1.2).close()
