@@ -1,15 +1,15 @@
 import numpy as np
-import vedo
-import vedo.colors as colors
-import vedo.utils as utils
 import vtk
+import vedo
+from vedo import colors
+from vedo import utils
 
 __doc__ = """
 Submodule to work with common format images
 
 .. image:: https://vedo.embl.es/images/basic/rotateImage.png
 """
-__all__ = ["Picture"]
+__all__ = ["Picture", "MatplotlibPicture"]
 
 
 #################################################
@@ -17,14 +17,14 @@ def _get_img(obj, flip=False):
     # get vtkImageData from numpy array
     obj = np.asarray(obj)
 
-    if obj.ndim == 3: # has shape (nx,ny, ncolor_alpha_chan)
+    if obj.ndim == 3:  # has shape (nx,ny, ncolor_alpha_chan)
         iac = vtk.vtkImageAppendComponents()
-        nchan = obj.shape[2] # get number of channels in inputimage (L/LA/RGB/RGBA)
+        nchan = obj.shape[2]  # get number of channels in inputimage (L/LA/RGB/RGBA)
         for i in range(nchan):
             if flip:
-                arr = np.flip(np.flip(obj[:,:,i], 0), 0).ravel()
+                arr = np.flip(np.flip(obj[:, :, i], 0), 0).ravel()
             else:
-                arr = np.flip(obj[:,:,i], 0).ravel()
+                arr = np.flip(obj[:, :, i], 0).ravel()
             arr = np.clip(arr, 0, 255)
             varb = utils.numpy2vtk(arr, dtype=np.uint8, name="RGBA")
             imgb = vtk.vtkImageData()
@@ -35,9 +35,9 @@ def _get_img(obj, flip=False):
         iac.Update()
         img = iac.GetOutput()
 
-    elif obj.ndim == 2: # black and white
+    elif obj.ndim == 2:  # black and white
         if flip:
-            arr = np.flip(obj[:,:], 0).ravel()
+            arr = np.flip(obj[:, :], 0).ravel()
         else:
             arr = obj.ravel()
         arr = np.clip(arr, 0, 255)
@@ -50,6 +50,61 @@ def _get_img(obj, flip=False):
     return img
 
 
+#################################################
+class MatplotlibPicture(vtk.vtkActor2D):
+    """
+    Embed a 2D matplotlib image in the 3D scene.
+
+    Parameters
+    ----------
+    fig : matplotlib.Figure, matplotlib.pyplot
+        the output from matplotlib
+
+    pos : list
+        2D (x,y) position in range [0,1], [0,0] being the bottom-left corner
+
+    size : list
+        resize image to this pixel size
+
+    scale : float
+        apply a scaling factor to the image
+
+    ontop : bool
+        keep image on top or not
+
+    padding : int
+        padding space to keep around the image
+    """
+    def __init__(self, fig, pos=(0,0), size=(), scale=1, ontop=False, padding=1):
+
+        vtk.vtkActor2D.__init__(self)
+
+        if hasattr(fig, "gcf"):
+            fig = fig.gcf()
+        fig.tight_layout(pad=padding)
+        fig.canvas.draw()
+
+        self.data = np.frombuffer(fig.canvas.tostring_rgb(), dtype=np.uint8)
+        self.data = self.data.reshape(fig.canvas.get_width_height()[::-1] + (3,))
+        self.picture = Picture(self.data)
+        if len(size):
+            self.picture.resize(np.array(size)*scale)
+        if scale != 1:
+            self.picture.scale(scale)
+
+        self.mapper = vtk.vtkImageMapper()
+        self.mapper.SetInputData(self.picture.inputdata())
+        self.mapper.SetColorWindow(255)
+        self.mapper.SetColorLevel(127.5)
+        self.SetMapper(self.mapper)
+        self.GetPositionCoordinate().SetCoordinateSystemToNormalizedViewport()
+        self.SetPosition(pos)
+        if ontop:
+            self.GetProperty().SetDisplayLocationToForeground()
+        else:
+            self.GetProperty().SetDisplayLocationToBackground()
+
+
 #################################################
 class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
     """
@@ -66,12 +121,13 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
     :param int,list channels: only select these specific rgba channels (useful to remove alpha)
     :param bool flip: flip xy axis convention (when input is a numpy array)
     """
+
     def __init__(self, obj=None, channels=3, flip=False):
 
         vtk.vtkImageActor.__init__(self)
         vedo.base.Base3DProp.__init__(self)
 
-        if utils.isSequence(obj) and len(obj): # passing array
+        if utils.isSequence(obj) and len(obj):  # passing array
             img = _get_img(obj, flip)
 
         elif isinstance(obj, vtk.vtkImageData):
@@ -92,7 +148,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
                 picr = vtk.vtkTIFFReader()
                 picr.SetOrientationType(vedo.settings.tiffOrientationType)
             else:
-                colors.printc("Cannot understand picture format", obj, c='r')
+                colors.printc("Cannot understand picture format", obj, c="r")
                 return
             picr.SetFileName(obj)
             self.filename = obj
@@ -125,21 +181,22 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         self._data = img
         self.SetInputData(img)
 
-        sx,sy,_ = img.GetDimensions()
-        self.shape = np.array([sx,sy])
+        sx, sy, _ = img.GetDimensions()
+        self.shape = np.array([sx, sy])
 
         self._mapper = self.GetMapper()
 
-
     def inputdata(self):
         """Return the underlying ``vtkImagaData`` object."""
         return self._data
 
     def dimensions(self):
+        """Return the picture dimension as number of pixels in x and y"""
         nx, ny, _ = self._data.GetDimensions()
         return np.array([nx, ny])
 
     def channels(self):
+        """Return the number of channels in picture"""
         return self._data.GetPointData().GetScalars().GetNumberOfComponents()
 
     def _update(self, data):
@@ -148,16 +205,16 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         self._mapper.SetInputData(data)
         self._mapper.Modified()
         nx, ny, _ = self._data.GetDimensions()
-        self.shape = np.array([nx,ny])
+        self.shape = np.array([nx, ny])
         return self
 
-    def clone(self, transform=False):
+    def clone(self, transformed=False):
         """Return an exact copy of the input Picture.
         If transform is True, it is given the same scaling and position."""
         img = vtk.vtkImageData()
         img.DeepCopy(self._data)
         pic = Picture(img)
-        if transform:
+        if transformed:
             # assign the same transformation to the copy
             pic.SetOrigin(self.GetOrigin())
             pic.SetScale(self.GetScale())
@@ -173,7 +230,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         if ext is None:
             return self._data.GetExtent()
         else:
-            self._data.SetExtent(ext[0],ext[1],ext[2],ext[3],0,0)
+            self._data.SetExtent(ext[0], ext[1], ext[2], ext[3], 0, 0)
             self._mapper.Modified()
             return self
 
@@ -199,7 +256,6 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         self.GetProperty().SetColorWindow(value)
         return self
 
-
     def crop(self, top=None, bottom=None, right=None, left=None, pixels=False):
         """Crop picture.
 
@@ -215,7 +271,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
 
         d = self.GetInput().GetDimensions()
         if pixels:
-            extractVOI.SetVOI(right, d[0]-left, bottom, d[1]-top, 0, 0)
+            extractVOI.SetVOI(right, d[0] - left, bottom, d[1] - top, 0, 0)
         else:
             bx0, bx1, by0, by1 = 0, d[0]-1, 0, d[1]-1
             if left is not None:   bx0 = int((d[0]-1)*left)
@@ -238,21 +294,23 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         value : int, optional
             intensity value (gray-scale color) of the padding. The default is 255.
         """
-        x0,x1,y0,y1,_z0,_z1 = self._data.GetExtent()
+        x0, x1, y0, y1, _z0, _z1 = self._data.GetExtent()
         pf = vtk.vtkImageConstantPad()
         pf.SetInputData(self._data)
         pf.SetConstant(value)
         if utils.isSequence(pixels):
-            pf.SetOutputWholeExtent(x0-pixels[0],x1+pixels[1],
-                                    y0-pixels[2],y1+pixels[3], 0,0)
+            pf.SetOutputWholeExtent(
+                x0 - pixels[0], x1 + pixels[1], y0 - pixels[2], y1 + pixels[3], 0, 0
+            )
         else:
-            pf.SetOutputWholeExtent(x0-pixels,x1+pixels, y0-pixels,y1+pixels, 0,0)
+            pf.SetOutputWholeExtent(
+                x0 - pixels, x1 + pixels, y0 - pixels, y1 + pixels, 0, 0
+            )
         pf.Update()
         img = pf.GetOutput()
         return self._update(img)
 
-
-    def tile(self, nx=4, ny=4, shift=(0,0)):
+    def tile(self, nx=4, ny=4, shift=(0, 0)):
         """
         Generate a tiling from the current picture by mirroring and repeating it.
 
@@ -265,16 +323,21 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         shift : list, optional
             shift in x and y in pixels. The default is 4.
         """
-        x0,x1,y0,y1,z0,z1 = self._data.GetExtent()
+        x0, x1, y0, y1, z0, z1 = self._data.GetExtent()
         constantPad = vtk.vtkImageMirrorPad()
         constantPad.SetInputData(self._data)
-        constantPad.SetOutputWholeExtent(int(x0+shift[0]+0.5), int(x1*nx+shift[0]+0.5),
-                                         int(y0+shift[1]+0.5), int(y1*ny+shift[1]+0.5), z0,z1)
+        constantPad.SetOutputWholeExtent(
+            int(x0 + shift[0] + 0.5),
+            int(x1 * nx + shift[0] + 0.5),
+            int(y0 + shift[1] + 0.5),
+            int(y1 * ny + shift[1] + 0.5),
+            z0,
+            z1,
+        )
         constantPad.Update()
         return Picture(constantPad.GetOutput())
 
-
-    def append(self, pictures, axis='z', preserveExtents=False):
+    def append(self, pictures, axis="z", preserveExtents=False):
         """
         Append the input images to the current one along the specified axis.
         Except for the append axis, all inputs must have the same extent.
@@ -305,9 +368,9 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
             if isinstance(p, vtk.vtkImageData):
                 ima.AddInputData(p)
             else:
-                ima.AddInputData(p._data)
+                ima.AddInputData(p.inputdata())
         ima.SetPreserveExtents(preserveExtents)
-        if axis   == "x":
+        if axis == "x":
             axis = 0
         elif axis == "y":
             axis = 1
@@ -315,7 +378,6 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         ima.Update()
         return self._update(ima.GetOutput())
 
-
     def resize(self, newsize):
         """Resize the image resolution by specifying the number of pixels in width and height.
         If left to zero, it will be automatically calculated to keep the original aspect ratio.
@@ -328,11 +390,11 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
             newsize = (old_dims * newsize + 0.5).astype(int)
 
         if not newsize[1]:
-            ar = old_dims[1]/old_dims[0]
-            newsize = [newsize[0], int(newsize[0]*ar+0.5)]
+            ar = old_dims[1] / old_dims[0]
+            newsize = [newsize[0], int(newsize[0] * ar + 0.5)]
         if not newsize[0]:
-            ar = old_dims[0]/old_dims[1]
-            newsize = [int(newsize[1]*ar+0.5), newsize[1]]
+            ar = old_dims[0] / old_dims[1]
+            newsize = [int(newsize[1] * ar + 0.5), newsize[1]]
         newsize = [newsize[0], newsize[1], old_dims[2]]
 
         rsz = vtk.vtkImageResize()
@@ -341,7 +403,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         rsz.SetOutputDimensions(newsize)
         rsz.Update()
         out = rsz.GetOutput()
-        out.SetSpacing(1,1,1)
+        out.SetSpacing(1, 1, 1)
         return self._update(out)
 
     def mirror(self, axis="x"):
@@ -353,7 +415,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         elif axis.lower() == "y":
             ff.SetFilteredAxis(1)
         else:
-            colors.printc("Error in mirror(): mirror must be set to x or y.", c='r')
+            colors.printc("Error in mirror(): mirror must be set to x or y.", c="r")
             raise RuntimeError()
         ff.Update()
         return self._update(ff.GetOutput())
@@ -362,7 +424,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         """Mirror picture along x or y axis. Same as mirror()."""
         return self.mirror(axis=axis)
 
-    def rotate(self, angle, center=(), scale=1, mirroring=False, bc='w', alpha=1):
+    def rotate(self, angle, center=(), scale=1, mirroring=False, bc="w", alpha=1):
         """
         Rotate by the specified angle (anticlockwise).
 
@@ -374,7 +436,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
             center of rotation (x,y) in pixels.
         """
         bounds = self.bounds()
-        pc = [0,0,0]
+        pc = [0, 0, 0]
         if center:
             pc[0] = center[0]
             pc[1] = center[1]
@@ -386,13 +448,13 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         transform = vtk.vtkTransform()
         transform.Translate(pc)
         transform.RotateWXYZ(-angle, 0, 0, 1)
-        transform.Scale(1/scale,1/scale,1)
+        transform.Scale(1 / scale, 1 / scale, 1)
         transform.Translate(-pc[0], -pc[1], -pc[2])
 
         reslice = vtk.vtkImageReslice()
         reslice.SetMirror(mirroring)
-        c = np.array(colors.getColor(bc))*255
-        reslice.SetBackgroundColor([c[0],c[1],c[2], alpha*255])
+        c = np.array(colors.getColor(bc)) * 255
+        reslice.SetBackgroundColor([c[0], c[1], c[2], alpha * 255])
         reslice.SetInputData(self._data)
         reslice.SetResliceTransform(transform)
         reslice.SetOutputDimensionality(2)
@@ -414,10 +476,10 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
     def bw(self):
         """Make it black and white using luminance calibration"""
         n = self._data.GetPointData().GetNumberOfComponents()
-        if n==4:
+        if n == 4:
             ecr = vtk.vtkImageExtractComponents()
             ecr.SetInputData(self._data)
-            ecr.SetComponents(0,1,2)
+            ecr.SetComponents(0, 1, 2)
             ecr.Update()
             img = ecr.GetOutput()
         else:
@@ -444,7 +506,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         gsf.SetInputData(self._data)
         if radius is not None:
             if utils.isSequence(radius):
-                gsf.SetRadiusFactors(radius[0],radius[1])
+                gsf.SetRadiusFactors(radius[0], radius[1])
             else:
                 gsf.SetRadiusFactor(radius)
 
@@ -507,7 +569,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         originalColor.Update()
         return self._update(originalColor.GetOutput())
 
-    def fft(self, mode='magnitude', logscale=12, center=True):
+    def fft(self, mode="magnitude", logscale=12, center=True):
         """Fast Fourier transform of a picture.
 
         :param float logscale: if non-zero, take the logarithm of the
@@ -522,24 +584,24 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         ffti.SetInputData(self._data)
         ffti.Update()
 
-        if 'mag' in mode:
+        if "mag" in mode:
             mag = vtk.vtkImageMagnitude()
             mag.SetInputData(ffti.GetOutput())
             mag.Update()
             out = mag.GetOutput()
-        elif 'real' in mode:
+        elif "real" in mode:
             extractRealFilter = vtk.vtkImageExtractComponents()
             extractRealFilter.SetInputData(ffti.GetOutput())
             extractRealFilter.SetComponents(0)
             extractRealFilter.Update()
             out = extractRealFilter.GetOutput()
-        elif 'imaginary' in mode:
+        elif "imaginary" in mode:
             extractImgFilter = vtk.vtkImageExtractComponents()
             extractImgFilter.SetInputData(ffti.GetOutput())
             extractImgFilter.SetComponents(1)
             extractImgFilter.Update()
             out = extractImgFilter.GetOutput()
-        elif 'complex' in mode:
+        elif "complex" in mode:
             out = ffti.GetOutput()
         else:
             colors.printc("Error in fft(): unknown mode", mode)
@@ -551,7 +613,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
             center.Update()
             out = center.GetOutput()
 
-        if 'complex' not in mode:
+        if "complex" not in mode:
             if logscale:
                 ils = vtk.vtkImageLogarithmicScale()
                 ils.SetInputData(out)
@@ -561,31 +623,31 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
 
         return Picture(out)
 
-    def rfft(self, mode='magnitude'):
+    def rfft(self, mode="magnitude"):
         """Reverse Fast Fourier transform of a picture."""
 
         ffti = vtk.vtkImageRFFT()
         ffti.SetInputData(self._data)
         ffti.Update()
 
-        if 'mag' in mode:
+        if "mag" in mode:
             mag = vtk.vtkImageMagnitude()
             mag.SetInputData(ffti.GetOutput())
             mag.Update()
             out = mag.GetOutput()
-        elif 'real' in mode:
+        elif "real" in mode:
             extractRealFilter = vtk.vtkImageExtractComponents()
             extractRealFilter.SetInputData(ffti.GetOutput())
             extractRealFilter.SetComponents(0)
             extractRealFilter.Update()
             out = extractRealFilter.GetOutput()
-        elif 'imaginary' in mode:
+        elif "imaginary" in mode:
             extractImgFilter = vtk.vtkImageExtractComponents()
             extractImgFilter.SetInputData(ffti.GetOutput())
             extractImgFilter.SetComponents(1)
             extractImgFilter.Update()
             out = extractImgFilter.GetOutput()
-        elif 'complex' in mode:
+        elif "complex" in mode:
             out = ffti.GetOutput()
         else:
             colors.printc("Error in rfft(): unknown mode", mode)
@@ -610,7 +672,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         :param list highcutoff: the cutoff frequencies
         :param int order: order determines sharpness of the cutoff curve
         """
-        #https://lorensen.github.io/VTKExamples/site/Cxx/ImageProcessing/IdealHighPass
+        # https://lorensen.github.io/VTKExamples/site/Cxx/ImageProcessing/IdealHighPass
         fft = vtk.vtkImageFFT()
         fft.SetInputData(self._data)
         fft.Update()
@@ -642,12 +704,11 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         butterworthReal.Update()
 
         caster = vtk.vtkImageCast()
-        caster. SetOutputScalarTypeToUnsignedChar()
+        caster.SetOutputScalarTypeToUnsignedChar()
         caster.SetInputData(butterworthReal.GetOutput())
         caster.Update()
         return self._update(caster.GetOutput())
 
-
     def blend(self, pic, alpha1=0.5, alpha2=0.5):
         """Take L, LA, RGB, or RGBA images as input and blends
         them according to the alpha values and/or the opacity setting for each input.
@@ -661,9 +722,16 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         blf.Update()
         return self._update(blf.GetOutput())
 
-
-    def warp(self, sourcePts=(), targetPts=(), transform=None, sigma=1,
-             mirroring=False, bc='w', alpha=1):
+    def warp(
+        self,
+        sourcePts=(),
+        targetPts=(),
+        transform=None,
+        sigma=1,
+        mirroring=False,
+        bc="w",
+        alpha=1,
+    ):
         """
         Warp an image using thin-plate splines.
 
@@ -707,9 +775,9 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
 
             for i in range(ns):
                 p = sourcePts[i]
-                ptsou.SetPoint(i, [p[0],p[1],0])
+                ptsou.SetPoint(i, [p[0], p[1], 0])
                 p = targetPts[i]
-                pttar.SetPoint(i, [p[0],p[1],0])
+                pttar.SetPoint(i, [p[0], p[1], 0])
 
             transform.SetSigma(sigma)
             transform.SetSourceLandmarks(pttar)
@@ -724,13 +792,12 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         reslice.SetResliceTransform(transform)
         reslice.SetInterpolationModeToCubic()
         reslice.SetMirror(mirroring)
-        c = np.array(colors.getColor(bc))*255
-        reslice.SetBackgroundColor([c[0],c[1],c[2], alpha*255])
+        c = np.array(colors.getColor(bc)) * 255
+        reslice.SetBackgroundColor([c[0], c[1], c[2], alpha * 255])
         reslice.Update()
         self.transform = transform
         return self._update(reslice.GetOutput())
 
-
     def invert(self):
         """
         Return an inverted picture (inverted in each color channel).
@@ -739,7 +806,6 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         data = 255 - np.array(rgb)
         return self._update(_get_img(data))
 
-
     def binarize(self, thresh=None, invert=False):
         """Return a new Picture where pixel above threshold are set to 255
         and pixels below are set to 0.
@@ -761,16 +827,16 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         """
         rgb = self.tonumpy()
         if rgb.ndim == 3:
-            intensity = np.sum(rgb, axis=2)/3
+            intensity = np.sum(rgb, axis=2) / 3
         else:
             intensity = rgb
 
         if thresh is None:
             vmin, vmax = np.min(intensity), np.max(intensity)
-            thresh = (vmax+vmin)/2
+            thresh = (vmax + vmin) / 2
 
         data = np.zeros_like(intensity).astype(np.uint8)
-        mask = np.where(intensity>thresh)
+        mask = np.where(intensity > thresh)
         if invert:
             data += 255
             data[mask] = 0
@@ -779,7 +845,6 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
 
         return self._update(_get_img(data, flip=True))
 
-
     def threshold(self, value=None, flip=False):
         """
         Create a polygonal Mesh from a Picture by filling regions with pixels
@@ -804,8 +869,8 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         msq = vtk.vtkMarchingSquares()
         msq.SetInputData(mgf.GetOutput())
         if value is None:
-            r0,r1 = self._data.GetScalarRange()
-            value = r0 + (r1-r0)/3
+            r0, r1 = self._data.GetScalarRange()
+            value = r0 + (r1 - r0) / 3
         msq.SetValue(0, value)
         msq.Update()
         if flip:
@@ -820,8 +885,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         ctr = vtk.vtkContourTriangulator()
         ctr.SetInputData(output)
         ctr.Update()
-        return vedo.Mesh(ctr.GetOutput(), c='k').bc('t').lighting('off')
-
+        return vedo.Mesh(ctr.GetOutput(), c="k").bc("t").lighting("off")
 
     def tomesh(self):
         """
@@ -829,8 +893,8 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         with each polygon vertex assigned a RGBA value.
         """
         dims = self._data.GetDimensions()
-        gr = vedo.shapes.Grid(s=dims[:2], res=(dims[0]-1, dims[1]-1))
-        gr.pos(int(dims[0]/2), int(dims[1]/2)).pickable(True).wireframe(False).lw(0)
+        gr = vedo.shapes.Grid(s=dims[:2], res=(dims[0] - 1, dims[1] - 1))
+        gr.pos(int(dims[0] / 2), int(dims[1] / 2)).pickable(True).wireframe(False).lw(0)
         self._data.GetPointData().GetScalars().SetName("RGBA")
         gr.inputdata().GetPointData().AddArray(self._data.GetPointData().GetScalars())
         gr.inputdata().GetPointData().SetActiveScalars("RGBA")
@@ -860,7 +924,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         narray = np.flip(narray, axis=0).astype(np.uint8)
         return narray
 
-    def rectangle(self, xspan, yspan, c='green5', alpha=1):
+    def rectangle(self, xspan, yspan, c="green5", alpha=1):
         """Draw a rectangle box on top of current image. Units are pixels.
 
         .. code-block:: python
@@ -875,15 +939,16 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         x1, x2 = xspan
         y1, y2 = yspan
 
-        r,g,b = vedo.colors.getColor(c)
-        c = np.array([r,g,b]) * 255
+        r, g, b = vedo.colors.getColor(c)
+        c = np.array([r, g, b]) * 255
         c = c.astype(np.uint8)
-        if alpha>1:
-            alpha=1
-        if alpha<=0:
+
+        if alpha > 1:
+            alpha = 1
+        if alpha <= 0:
             return self
         alpha2 = alpha
-        alpha1 = 1-alpha
+        alpha1 = 1 - alpha
 
         nx, ny = self.dimensions()
         if x2>nx : x2=nx-1
@@ -893,34 +958,34 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         narrayA = self.tonumpy()
 
         canvas_source = vtk.vtkImageCanvasSource2D()
-        canvas_source.SetExtent(0, nx-1, 0, ny-1, 0, 0)
+        canvas_source.SetExtent(0, nx - 1, 0, ny - 1, 0, 0)
         canvas_source.SetScalarTypeToUnsignedChar()
         canvas_source.SetNumberOfScalarComponents(nchan)
-        canvas_source.SetDrawColor(255,255,255)
+        canvas_source.SetDrawColor(255, 255, 255)
         canvas_source.FillBox(x1, x2, y1, y2)
         canvas_source.Update()
         image_data = canvas_source.GetOutput()
 
         vscals = image_data.GetPointData().GetScalars()
-        narrayB = vedo.utils.vtk2numpy(vscals).reshape(ny,nx,nchan)
+        narrayB = vedo.utils.vtk2numpy(vscals).reshape(ny, nx, nchan)
         narrayB = np.flip(narrayB, axis=0)
-        narrayC = np.where(narrayB < 255, narrayA, alpha1*narrayA+alpha2*c)
+        narrayC = np.where(narrayB < 255, narrayA, alpha1 * narrayA + alpha2 * c)
         return self._update(_get_img(narrayC))
 
-    def line(self, p1, p2, lw=2, c='k2', alpha=1):
+    def line(self, p1, p2, lw=2, c="k2", alpha=1):
         """Draw a line on top of current image. Units are pixels."""
         x1, x2 = p1
         y1, y2 = p2
 
-        r,g,b = vedo.colors.getColor(c)
-        c = np.array([r,g,b]) * 255
+        r, g, b = vedo.colors.getColor(c)
+        c = np.array([r, g, b]) * 255
         c = c.astype(np.uint8)
-        if alpha>1:
-            alpha=1
-        if alpha<=0:
+        if alpha > 1:
+            alpha = 1
+        if alpha <= 0:
             return self
         alpha2 = alpha
-        alpha1 = 1-alpha
+        alpha1 = 1 - alpha
 
         nx, ny = self.dimensions()
         if x2>nx : x2=nx-1
@@ -930,61 +995,62 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         narrayA = self.tonumpy()
 
         canvas_source = vtk.vtkImageCanvasSource2D()
-        canvas_source.SetExtent(0, nx-1, 0, ny-1, 0, 0)
+        canvas_source.SetExtent(0, nx - 1, 0, ny - 1, 0, 0)
         canvas_source.SetScalarTypeToUnsignedChar()
         canvas_source.SetNumberOfScalarComponents(nchan)
-        canvas_source.SetDrawColor(255,255,255)
+        canvas_source.SetDrawColor(255, 255, 255)
         canvas_source.FillTube(x1, x2, y1, y2, lw)
         canvas_source.Update()
         image_data = canvas_source.GetOutput()
 
         vscals = image_data.GetPointData().GetScalars()
-        narrayB = vedo.utils.vtk2numpy(vscals).reshape(ny,nx,nchan)
+        narrayB = vedo.utils.vtk2numpy(vscals).reshape(ny, nx, nchan)
         narrayB = np.flip(narrayB, axis=0)
-        narrayC = np.where(narrayB < 255, narrayA, alpha1*narrayA+alpha2*c)
+        narrayC = np.where(narrayB < 255, narrayA, alpha1 * narrayA + alpha2 * c)
         return self._update(_get_img(narrayC))
 
-    def triangle(self, p1, p2, p3, c='red3', alpha=1):
+    def triangle(self, p1, p2, p3, c="red3", alpha=1):
         """Draw a triangle on top of current image. Units are pixels."""
         x1, y1 = p1
         x2, y2 = p2
         x3, y3 = p3
 
-        r,g,b = vedo.colors.getColor(c)
-        c = np.array([r,g,b]) * 255
+        r, g, b = vedo.colors.getColor(c)
+        c = np.array([r, g, b]) * 255
         c = c.astype(np.uint8)
 
-        if alpha>1:
-            alpha=1
-        if alpha<=0:
+        if alpha > 1:
+            alpha = 1
+        if alpha <= 0:
             return self
         alpha2 = alpha
-        alpha1 = 1-alpha
+        alpha1 = 1 - alpha
 
         nx, ny = self.dimensions()
-        if x1>nx : x1=nx
-        if x2>nx : x2=nx
-        if x3>nx : x3=nx
-        if y1>ny : y1=ny
-        if y2>ny : y2=ny
-        if y3>ny : y3=ny
+        x1 = min(x1, nx)
+        x2 = min(x2, nx)
+        x3 = min(x3, nx)
+
+        y1 = min(y1, ny)
+        y2 = min(y2, ny)
+        y3 = min(y3, ny)
 
         nchan = self.channels()
         narrayA = self.tonumpy()
 
         canvas_source = vtk.vtkImageCanvasSource2D()
-        canvas_source.SetExtent(0, nx-1, 0, ny-1, 0, 0)
+        canvas_source.SetExtent(0, nx - 1, 0, ny - 1, 0, 0)
         canvas_source.SetScalarTypeToUnsignedChar()
         canvas_source.SetNumberOfScalarComponents(nchan)
-        canvas_source.SetDrawColor(255,255,255)
+        canvas_source.SetDrawColor(255, 255, 255)
         canvas_source.FillTriangle(x1, y1, x2, y2, x3, y3)
         canvas_source.Update()
         image_data = canvas_source.GetOutput()
 
         vscals = image_data.GetPointData().GetScalars()
-        narrayB = vedo.utils.vtk2numpy(vscals).reshape(ny,nx,nchan)
+        narrayB = vedo.utils.vtk2numpy(vscals).reshape(ny, nx, nchan)
         narrayB = np.flip(narrayB, axis=0)
-        narrayC = np.where(narrayB < 255, narrayA, alpha1*narrayA+alpha2*c)
+        narrayC = np.where(narrayB < 255, narrayA, alpha1 * narrayA + alpha2 * c)
         return self._update(_get_img(narrayC))
 
 #    def circle(self, center, radius, c='k3', alpha=1): # not working
@@ -1021,19 +1087,21 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
 #        narrayC = np.where(narrayB < 255, narrayA, alpha1*narrayA+alpha2*c)
 #        return self._update(_get_img(narrayC))
 
-    def text(self, txt,
-                   pos=(0,0,0),
-                   s=1,
-                   c=None,
-                   alpha=1,
-                   bg=None,
-                   font="Theemim",
-                   dpi=500,
-                   justify="bottom-left",
-        ):
+    def text(
+        self,
+        txt,
+        pos=(0, 0, 0),
+        s=1,
+        c=None,
+        alpha=1,
+        bg=None,
+        font="Theemim",
+        dpi=500,
+        justify="bottom-left",
+    ):
         """Build an image from a string."""
 
-        if c is None: # automatic black or white
+        if c is None:  # automatic black or white
             if vedo.plotter_instance and vedo.plotter_instance.renderer:
                 c = (0.9, 0.9, 0.9)
                 if np.sum(vedo.plotter_instance.renderer.GetBackground()) > 1.5:
@@ -1074,12 +1142,12 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
             tp.SetFrameColor(bgcol)
             tp.FrameOn()
 
-        #GetConstrainedFontSize (const vtkUnicodeString &str,
+        # GetConstrainedFontSize (const vtkUnicodeString &str,
         # vtkTextProperty *tprop, int targetWidth, int targetHeight, int dpi)
         fs = r.GetConstrainedFontSize(txt, tp, 900, 1000, dpi)
         tp.SetFontSize(fs)
 
-        r.RenderString(tp, txt, img, [1,1], dpi)
+        r.RenderString(tp, txt, img, [1, 1], dpi)
         # RenderString (vtkTextProperty *tprop, const vtkStdString &str,
         #   vtkImageData *data, int textDims[2], int dpi, int backend=Default)
 
@@ -1089,8 +1157,8 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         self.SetPosition(pos)
         x0, x1 = self.xbounds()
         if x1 != x0:
-            sc = s/(x1-x0)
-            self.SetScale(sc,sc,sc)
+            sc = s / (x1 - x0)
+            self.SetScale(sc, sc, sc)
         return self
 
     def modified(self):
